<?php

namespace Drupal\elastic_apm;

/**
 * Interface for the APIService object.
 *
 * @package Drupal\elastic_apm
 */
interface ApiServiceInterface {

  /**
   * Returns TRUE if the user has enabled Elastic APM PHP Agent.
   *
   * @return bool
   *   TRUE if it is enabled, FALSE otherwise.
   */
  public function isPhpAgentEnabled();

  /**
   * Returns TRUE if the user has enabled Elastic APM Rum Agent.
   *
   * @return bool
   *   TRUE if it is enabled, FALSE otherwise.
   */
  public function isRumAgentEnabled();

  /**
   * Returns the RUM Agent configuration array.
   *
   * @return array
   *   The RUM Agent configuration array.
   */
  public function getRumAgentConfig();

  /**
   * Returns the tag configuration array.
   *
   * @return array
   *   The tag configuration array.
   */
  public function getTagConfig();

  /**
   * Returns the parsed tag patterns array.
   *
   * It ignores malformed patterns.
   *
   * @param string $tag_config
   *   The tag config string.
   *
   * @return array
   *   The parsed tag config array.
   */
  public function parseTagPatterns($tag_config);

  /**
   * Validates the given tag pattern.
   *
   * Checks whether the given pattern follows the expected format:
   * pattern:tag-key|tag-value
   * /product/*:provider|commerce
   * entity.commerce_product.canonical:provider|commerce
   *
   * @param string $pattern
   *   The pattern to validate.
   *
   * @return string[]
   *   Returns an array containing the malformed patterns, if any were found.
   */
  public function validateTagPattern($pattern);

  /**
   * Returns TRUE if current path is configured to be monitored by Elastic APM.
   *
   * @return bool
   *   TRUE if the current path should be monitored, FALSE otherwise.
   */
  public function shouldMonitor();

}
