<?php

namespace Drupal\elastic_apm\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * PHP Agent settings form for the Elastic APM.
 *
 * @package Drupal\elastic_apm\Form
 */
class PhpAgentSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'elastic_apm_php_agent_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function getEditableConfigNames() {
    return ['elastic_apm.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('elastic_apm.settings');

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('phpAgent.status'),
      '#description' => $this->t(
        '<strong>If the PHP extension is enabled and properly configured transactions will be sent to the APM server regardless of this setting.</strong> This setting determines whether to make alterations on transactions such as adding Drupal-specific labels and spans.'
      ),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $this->config('elastic_apm.settings')
      ->set('phpAgent.status', $values['status'])
      ->save();

    parent::submitForm($form, $form_state);
  }

}
